@@ -51,7 +51,7 @@ test_that("posix values mapped to colours", {
 test_that("matrix palette accepted", {
   ##
   m <- grDevices::colorRamp(c("red","green","blue"))(0:4/4)
-  expect_true(all(colour_values(1:5, palette = m) == c("#FF0000FF", "#808000FF", "#00FF00FF", "#008080FF", "#0000FFFF")))
+  expect_true(all(colour_values(c(1:5), palette = m) == c("#FF0000FF", "#807F00FF","#00FF00FF", "#008080FF", "#0000FFFF")))
   ## This doesn't exactly equal
   #grDevices::colorRampPalette(c("red","green","blue"))(5)
   ## I 'think' because of boost's interpolation
@@ -63,7 +63,7 @@ test_that("matrix palette accepted", {
 
   alpha <- c(0, 100, 150, 200, 255)
   m <- cbind( grDevices::colorRamp(c("red","green","blue"))(0:4/4), alpha )
-  expect_true(all(colour_values(1:5, palette = m) == c("#FF000000", "#80800064", "#00FF0096", "#008080C8", "#0000FFFF")))
+  expect_true(all(colour_values(c(1:5), palette = m) == c("#FF000000", "#807F0064","#00FF0096", "#008080C8", "#0000FFFF")))
 
   ## string data
   expect_true( all( colour_values(letters[1:5], palette = m) == colour_values(1:5, palette = m) ) )
